spannertools.SlurSpanner
========================

.. abjad-lineage:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner

.. autoclass:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.append
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.append_left
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.attach
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.components
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.detach
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.direction
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.extend
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.extend_left
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.fracture
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.fuse
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.get_duration
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.get_timespan
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.index
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.leaves
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.override
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.pop
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.pop_left
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.set
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__call__
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__contains__
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__copy__
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__eq__
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__getitem__
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__len__
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__lt__
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__ne__
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__repr__

Bases
-----

- :py:class:`spannertools.DirectedSpanner <abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner>`

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.leaves
   :noindex:

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.override
   :noindex:

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.set
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.direction
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.append
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.attach
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.detach
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.get_duration
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.get_timespan
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.index
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.pop_left
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__call__
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__repr__
   :noindex:
